--[[
Top Parses on Boss Tooltip
Version: 1.0
]]--

local _, addon = ...;

-- Color code information for the different types of tips:
-- Important:	Green
-- Interrupt:	Orange
-- Healer Note: Light Blue
-- Blank:		Default Blizzard color
local parseColors = {
	["Important"] = {1,0.57,0.12},
	["Defensives"] = {1,0.57,0.12},
	["Interrupts"] = {0.37,0.92,1},
	["PriorityTargets"] = {1, 1, 0},
	["Fluff"] = {1, 1, 1},
	["Advanced"] = {0.75, 0.55, 0.35},	
	
	["DRUID"] = {1, 0.49, 0.04},
	["HUNTER"] = {0.67, 0.83, 0.45},
	["MAGE"] = {0.41, 0.8, 0.94},
	["PALADIN"] = {0.96, 0.55, 0.73},
	["PRIEST"] = {1, 1, 1},
	["ROGUE"] = {1, 0.96, 0.41},
	["SHAMAN"] = {0, 0.44, 0.87},
	["WARRIOR"] = {0.78, 0.61, 0.43},
	["WARLOCK"] = {0.58, 0.51, 0.79}

}

local classList =  {
	DRUID = true,
	HUNTER = true,
	MAGE = true,
	PALADIN = true,
	PRIEST = true,
	ROGUE = true,
	SHAMAN = true,
	WARRIOR = true,
	WARLOCK = true
}

local iconList = {
	PriorityTargets = "ability_hunter_markedfordeath",
	Interrupts = "ability_kick",
	Defensives = "inv_shield_05",
	Important = "ability_dualwield",
	Legion = "ability_dualwield",
	
	DRUID = "classicon_druid",		
	HUNTER = "classicon_hunter",
	MAGE = "classicon_mage",
	PALADIN = "classicon_paladin",
	PRIEST = "classicon_priest",
	ROGUE = "classicon_rogue",
	SHAMAN = "classicon_shaman",
	WARRIOR = "classicon_warrior",
	WARLOCK = "classicon_warlock",

}

local function RGBToHex(r, g, b)
	r = r <= 1 and r >= 0 and r or 0
	g = g <= 1 and g >= 0 and g or 0
	b = b <= 1 and b >= 0 and b or 0
	return string.format("%02x%02x%02x", r*255, g*255, b*255)
end


-- The addline function hooks into the WoW API to add a line to an NPC's tooltip.
local function addFrameLine(tooltip, tips, type, class)

	local found = false
	-- Check if we already added to this tooltip. This prevents writing the same thing to the tooltip multiple times.
	if not TPBT_HeaderPanel:IsVisible() then addon:setEnabled() end
	
	for i = 1,15 do
		local frame = _G[tooltip:GetName() .. "TextLeft" .. i]
		local text
		if frame then text = frame:GetText() end
		if text and text == type then found = true break end
	end


	-- If we haven't added to the NPC tooltip yet, proceed.

	if not found then

		-- Remember we are passing in an array {"HEALER", "HealersOnly"}} in our example so we'll iterate through each pair here.
		for i, tip in ipairs(tips) do
			-- tip[1] is the category indicator and we'll use that to decide whether we should show this tooltip or not.

			if TPBTConfig[tip[1]] or -- Show if tip type turned on, or if it's using an old Legion tag.

				(tip[1] == class and TPBTConfig["ClassChoice"] == "Show my class only") or
				(classList[tip[1]] and TPBTConfig["ClassChoice"] == "Show all classes") then

					local r,g,b = parseColors[tip[1]][1], parseColors[tip[1]][2], parseColors[tip[1]][3]
					local lineHex = RGBToHex(r, g, b)
					local tipBase = TPBT_ParseText:GetText() or ""

					if iconList[tip[1]] then -- Check if Icon exists
						if TPBTConfig.ShowFrame == "Show in separate frame" then 
							TPBT_ParseText:SetText(tipBase .. ((("|T%s:0|t"):format("Interface\\Icons\\"..iconList[tip[1]]).. "|cff" .. lineHex .. " " .. tip[2] .. "|r" .. "\n"))) 
						else
							tooltip:AddLine((("|T%s:0|t"):format("Interface\\Icons\\"..iconList[tip[1]])..tip[2]),r,g,b)
						end
					elseif parseColors[tip[1]] then -- Check if color exists
						if TPBTConfig.ShowFrame == "Show in separate frame" then 
							TPBT_ParseText:SetText(tipBase .. "|cff" .. lineHex .. " " .. tip[2] .. "|r" .. "\n")
						else
							tooltip:AddLine(tip[2],r,g,b)
						end
					else -- There is no icon or color assigned to the category so a plain line will be added instead.
						if TPBTConfig.ShowFrame == "Show in separate frame" then 
							TPBT_ParseText:SetText(tipBase .. " " .. tip[2] .. "\n")
						else
							tooltip:AddLine(tip[2])
						end
					end

			end
		end
		
		--tooltip:Show() -- This is necessary to actually update the tooltip whenever we add anything to it.
	end
end


-- This starts the ball rolling. This function is called whenever an NPC tooltip is moused over.
GameTooltip:HookScript("OnTooltipSetUnit", function(self)

  if TPBTConfig.ShowFrame == "Show in separate frame" and TPBTConfig.TargetTrigger == "Show targeted mob" then return end -- Tiny Snippet to disable the tooltip hook if targeting is selected instead.
  if TPBTConfig.ShowFrame == "Show in separate frame" and TPBTConfig.TargetTrigger == "Show mouseover" and TPBT_onBoss then return end -- Disable tooltip hook if player is using frame + Mouseover but is on boss
  
  local unit = select(2, self:GetUnit()) -- This grabs information about the unit we have targeted.

  local _, class, _ = UnitClass("player")
 
	if unit then

		local guid = UnitGUID(unit) or ""
		local id = tonumber(guid:match("-(%d+)-%x+$"), 10) -- This is the mobs ID. Don't worry about the regex.
		local name = UnitName(unit) or ""
		
		-- Check our dictionary to see if we actually have any tips for the mob targeted.
		if tipsMap[id] then

			-- Don't remove active tip if you accidentally mouse over ally.
			TPBT_ParseText:SetText("")
			TPBT_MobName:SetText(name)
		
			if TPBTConfig.ShowFrame == "Show in separate frame" then 
				addFrameLine(TPBT_ParsePanel, tipsMap[id], "NPC ID:", class) 
			else
				addFrameLine(GameTooltip, tipsMap[id], "NPC ID:", class)
			end
		
		elseif UnitIsEnemy(unit, "player") then
			TPBT_ParseText:SetText("")
			TPBT_MobName:SetText(name)
		end
	
  end 
end)




-- This starts the ball rolling on a mob target.
function addon:getTarget(mobType)
  
  local guid = UnitGUID(mobType) -- This grabs information about the unit we have targeted.
  
  local _, class, _ = UnitClass("player")
  
  --print("GUID: " .. UnitGUID("boss1"))
  
  if guid then
    --local guid = UnitGUID(unit) or ""
    local id = tonumber(guid:match("-(%d+)-%x+$"), 10) -- This is the mobs ID. Don't worry about the regex.
	local name = UnitName(mobType) or ""
	
	-- Check our dictionary to see if we actually have any tips for the mob targeted.
	if tipsMap[id]  then
		-- Don't remove active tip if you accidentally mouse over ally.
		
		TPBT_ParseText:SetText("")		
		TPBT_MobName:SetText(name)
		
		if TPBTConfig.ShowFrame == "Show in separate frame" then 
			addFrameLine(TPBT_ParsePanel, tipsMap[id], "NPC ID:", class) 
		else
			addFrameLine(GameTooltip, tipsMap[id], "NPC ID:", class)
		end
		
		--addFrameLine(TPBT_ParsePanel, tipsMap[id], "NPC ID:", class)
		--addLine(GameTooltip, tipsMap[id], "NPC ID:", class)		

	elseif 	UnitIsEnemy(mobType, "player") then
		TPBT_ParseText:SetText("")
		TPBT_MobName:SetText(name)
		
	end
	

	
  end
end
